@@ -1,6 +1,6 @@
 #' Automatically relabel factor levels, collapse as necessary
 #'
-#' @param .f A factor.
+#' @param .f A factor (or character vector).
 #' @param .fun A function to be applied to each level. Must accept one
 #'   character argument and return a character vector of the same length as
 #'   its input.
@@ -26,10 +26,11 @@
 #' rincome2 <- fct_relabel(gss_cat$rincome, convert_income)
 #' fct_count(rincome2)
 fct_relabel <- function(.f, .fun, ...) {
+  f <- check_factor(.f)
   .fun <- rlang::as_function(.fun)
 
-  old_levels <- levels(.f)
+  old_levels <- levels(f)
   new_levels <- .fun(old_levels, ...)
 
-  lvls_revalue(.f, new_levels)
+  lvls_revalue(f, new_levels)
 }
